/* RCS Information:
 *
 * $Id$
 * $Revision$
 * $Date$
 * $Author$
 * $Locker$
 * 
 */

/******************************************************************************
 *
 *  Copyright (C) 2002, Bill Pierce
 *  This file is part of the portable_time library.
 *
 *  The portable_time library is free software; you can 
 *  redistribute it and/or modify it under the terms of the 
 *  GNU Library General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The portable_time library is distributed in the hope that 
 *  it will be useful, but WITHOUT ANY WARRANTY; without even 
 *  the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 *  PARTICULAR PURPOSE.  See the GNU Library General Public 
 *  License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with the timeout action libary; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Bill Pierce can be contacted at:
 *  7862 NE 148th St.
 *  Kenmore, WA 98028
 *
 * Name --  portable_time.h
 *
 * Purpose -- define some portable functions that wrap OS-dependent
 *            system time functions.
 *
 * Remarks --  
 *
 * Known bugs --  
 *
 * Applicable Invariants -- 
 *
 * Supported Platforms -- 
 *
 * Win32 circa NT, 2000,    compile under cl,  define MS_WIN32
 * Solaris circa 2.7,       compile under cc   
 * 
 * Language Version --  C - GNU/Linux 
 *
 * Author --  Bill Pierce, 
 *
 * Origination Date -- 12-30-01 
 * 
 *****************************************************************************/

#ifdef MS_WIN32
   #include <sys/timeb.h>
#else
   #include <sys/time.h>
#endif

/* This is a portable system time data structure. */
typedef struct time_now {
     time_t seconds_since_epoch;
     int    milliseconds;
} TIME_NOW;

/* This is a portable time function.  That is, it should work the 
 * same for client callers on Windows and UNIX.  It operates like the <time.h> 
 * time() function, but at millisecond precision.  This function 
 * returns a structure representing the current time.  It will also
 * set the pointer argument passed in.
 */
TIME_NOW portable_time(TIME_NOW * p_now);

/* This is a portable time difference function.  That is, it should 
 * work the same for client callers on Windows an UNIX. 
 * It operates like the <time.h> 
 * difftime() function, but at millisecond precision.  This function returns
 * the difference between the two time structures passed in in 
 * seconds as a double precision floating point number.
 */
double portable_difftime(TIME_NOW t_later, TIME_NOW t_before);

/* Sleep the calling thread the specified number of milliseconds. */
void portable_sleep_ms(unsigned int sleep_in_ms);

 /*****************************************************************************
 ** $Log: $
 *****************************************************************************/

